#include "listupdatedialog.h"
#include <QDebug>
#include <QPushButton>
#include <QGroupBox>
#include <QHBoxLayout>
#include <QListWidget>
#include <QVBoxLayout>
#include "certificate.h"

ListUpdateDialog::ListUpdateDialog(QDialog *parent,
                                   const CertificateList &listToInstall) :
    QDialog(parent),
    mCertificateList(listToInstall)
{
    qDebug() << "I am a happy list update dialog";
    setupGUI();
}

void ListUpdateDialog::setupGUI()
{
    /* Top level layout / widgets */
    QVBoxLayout *topLayout = new QVBoxLayout;
    QHBoxLayout *listLayout = new QHBoxLayout;
    QPushButton *executeUpdate = new QPushButton(tr("Update Stores"));

    /* The remove groups */
    QVBoxLayout *removeGroupLayout = new QVBoxLayout;
    mRemoveListWidget = new QListWidget;
    removeGroupLayout->addWidget(mRemoveListWidget);
    QGroupBox *removeGroup = new QGroupBox(tr("Select certificates to be removed"));
    removeGroup->setLayout(removeGroupLayout);

    foreach (const Certificate& cert, mCertificateList.getRemoveCertificates()) {
        if (!cert.isValid()) {
            qWarning() << "Invalid certificate in list";
            continue;
        }
        QListWidgetItem* item = new QListWidgetItem(cert.shortDescription());
        item->setFlags(item->flags() | Qt::ItemIsUserCheckable);
        item->setCheckState(Qt::Checked);
        mRemoveListWidget->addItem(item);
    }

    /* The install group */
    QVBoxLayout *installGroupLayout = new QVBoxLayout;
    mInstallListWidget = new QListWidget;
    QGroupBox *installGroup = new QGroupBox(tr("Select certificates to install"));
    installGroupLayout->addWidget(mInstallListWidget);
    installGroup->setLayout(installGroupLayout);

    foreach (const Certificate& cert, mCertificateList.getInstallCertificates()) {
        if (!cert.isValid()) {
            qWarning() << "Invalid certificate in list";
            continue;
        }
        QListWidgetItem* item = new QListWidgetItem(cert.shortDescription());
        item->setFlags(item->flags() | Qt::ItemIsUserCheckable);
        item->setCheckState(Qt::Checked);
        mInstallListWidget->addItem(item);
    }

    /* Add groups to layout */
    listLayout->addWidget(installGroup);
    listLayout->addWidget(removeGroup);

    /* Fill top level layout */
    topLayout->addLayout(listLayout);
    topLayout->addWidget(executeUpdate);

    setLayout(topLayout);

    return;
}

void ListUpdateDialog::executeUpdate() {

}
